Learn R Programming

bayesLopod (version 1.0.1)

Andropogon_shape: Number of detection of Andropogon gerardii and it's target group in several counties in the Midwest

Description

Number of detection of Andropogon gerardii and it's target group in several counties in the Midwest

Usage

Andropogon_shape

Arguments

Format

An object of class SpatialPolygonsDataFrame with 617 rows and 3 columns.