Learn R Programming

bayesLopod (version 1.0.1)

lopodTrace: Plots the values of model parameters for each chain across iterations

Description

Plots the values of model parameters for each chain across iterations

Usage

lopodTrace(LopodModel, params = "lp__", inc_warmup = FALSE)

Arguments

LopodModel

A LopodModel object

params

Parameters to be plotted. Default is "lp__" which plots the log posterior probability

inc_warmup

Boolean. If true, warm-up iterations are plotted. Default is FALSE.

Value

A ggplot object.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
data("simSpRecords", package = "bayesLopod")
data("simSpSamplingEffort", package = "bayesLopod")
simSpRasters = xyToRaster(xyRecords = simSpRecords,xySamplingEffort = simSpSamplingEffort,
basemap = NULL, nrows = 50, extentExpansion = 0)
ld_Raster_adMatrix = rasterLopodData(rasterN = simSpRasters[["samplingEffort"]],
rasterY = simSpRasters[["spDetections"]], Adjacency = TRUE )
mLopodRaster = modelLopod(LopodData = ld_Raster_adMatrix, varP = TRUE, q = NULL,
pmin = 0.1, CAR = FALSE, nChains = 4,warmup = 500,sampling = 100,nCores = 4)
lopodTrace(mLopodRaster, inc_warmup = FALSE, params = c("p","q"))

data("Andropogon_shape", package = "bayesLopod")
ld_Shape = shapeLopodData(Shapefile = Andropogon_shape, fieldN = "sampEffort",
fieldY = "detections",  Adjacency = TRUE, keepFields = FALSE)
mLopodShape = modelLopod(LopodData = ld_Shape, varP = TRUE, q = NULL,
pmin = 0, CAR = TRUE, nChains = 4,warmup = 500,sampling = 100,nCores =4)
lopodTrace(mLopodShape, inc_warmup = TRUE)
# }

Run the code above in your browser using DataLab