Internal - Create a Raster object with Study Area from Raster data
rasterStudyArea(DistStak, maxDist, extSample = 0.025, extDetection = 0.15)Stack object distance to Sampled cells and detections (in that order).
Maximum distance in Raster
Number between 0 and 1. Maximum distance (relative to the diagonal of the raster) from a sampled cell that should be included in the study area. If 0, there is no extrapolation to not-sampled cells.
Number between 0 and 1. Maximum distance (relative to the diagonal of the raster) from cell in which the species was detected that should be included in the study area. If 0, there is no extrapolation to no-sampled cells.
A Raster object with Study Area.